#!/bin/sh

# Script for creating config(s) structure introduced with version v1.12.
# This script can be called from UpdateScript.sh in order to obtain new struct directly with an
# update.

cd /var/Counter
if [ "0" -ne "$?" ] ; then
    logger "CreateConfigStructure.sh: Cannot cd into /var/Counter"
    exit 1
fi

set -e    # Script exists immediately on error

if [ -d configs/0 ] ; then
    # New config structure (>= v1.12) exists. Nothing to do:
    exit 0
fi

# The new config structure has to be created:
mkdir -p configs/0 DefaultConfigs/0 DeviceSpecific

for i in `seq 1 31` ; do
    mkdir configs/${i}
    touch configs/${i}/_invalid

    mkdir DefaultConfigs/${i}
    touch DefaultConfigs/${i}/_invalid
done

# Move existing config files to specific new dirs:
mv config/intern_320x240.ini              DeviceSpecific/
mv config/intern_640x480.ini              DeviceSpecific/
mv config/intern_relative_calib.param     DeviceSpecific/
mv config/intern_relative_calib_vga.param DeviceSpecific/
mv config/left.lut                        DeviceSpecific/
mv config/leftx.vgalut                    DeviceSpecific/
mv config/lefty.vgalut                    DeviceSpecific/
mv config/rectified_320x240.ini           DeviceSpecific/
mv config/rectified_640x480.ini           DeviceSpecific/
mv config/right.lut                       DeviceSpecific/
mv config/rightx.vgalut                   DeviceSpecific/
mv config/righty.vgalut                   DeviceSpecific/

# The default files are obsolete and shall not be transferred into new structure:
rm -f config/*_default*

# The remaining files shall be in the default configuration 0:
mv config/* configs/0/

# The DefaultConfigs/0 directory remains empty.

rm -rf config

ln -s configs/0 config

# Extract network settings from U-Boot parameters:
IPADDR=`fw_printenv ipaddr     2>/dev/null |sed -e's/^.*=//'`
NETMASK=`fw_printenv netmask   2>/dev/null |sed -e's/^.*=//'`
GATEWAY=`fw_printenv serverip  2>/dev/null |sed -e's/^.*=//'`
HOSTNAME=`fw_printenv hostname 2>/dev/null |sed -e's/^.*=//'`

echo -e "[StaticNetworkSettings]\nIPv4=${IPADDR}\nNetmask=${NETMASK}" >config/network_settings.ini
echo ${GATEWAY}    >config/default_gateway
echo ${HOSTNAME}   >config/hostname

# Remove "$(ba2) " from UBoot paraemter bc_f. So the kernel does not get the IP settings:
NEW_BC_F=`fw_printenv |egrep '^bc_f=' |sed -e's/$(ba2) //' |sed -e's/^bc_f=//'`
fw_setenv bc_f "${NEW_BC_F}" >/dev/null
