#!/bin/sh

### script file name
SCRIPT_NAME=$(basename $0)

PATCH_TOOL="./Update_PatchMaxDisparity"

CONFIGS_DIR="/var/Counter/configs/"
CONFIGS_DIR_DEFAULT="/var/Counter/DefaultConfigs/"

# exit codes
EXIT_OK=0 #success
EXIT_NOTHING_TODO=1 #nothing to do
EXIT_ERROR=2 #error



# version check (patch MaxDisparity only if current version if < 2.40))
VERSION_CURRENT=`cat /version.txt`
CUR_VER_MAJOR=`echo ${VERSION_CURRENT} | awk 'BEGIN {FS="."}{print $1}'`
CUR_VER_MINOR=`echo ${VERSION_CURRENT} | awk 'BEGIN {FS="."}{print $2}'`
REF_VER_MAJOR=2
REF_VER_MINOR=40
if [ ${CUR_VER_MAJOR} -lt ${REF_VER_MAJOR} ] ; then
    # current version is lower than reference version, patch it (do nothing here)
    test 2>/dev/null
elif [[ ${CUR_VER_MAJOR} -eq ${REF_VER_MAJOR} && ${CUR_VER_MINOR} -lt ${REF_VER_MINOR} ]] ; then
    # current version is lower than reference version, patch it (do nothing here)
    test 2>/dev/null
else
    exit ${EXIT_NOTHING_TODO}
fi


# convert
# loop all configs directories
for i in `seq 0 31` ; do
    CUR_DIR=${CONFIGS_DIR}${i}/
    ${PATCH_TOOL} "${CUR_DIR}"
    RET=$?
    if [ "${EXIT_ERROR}" -eq "${RET}" ] ; then
        exit ${EXIT_ERROR}
    fi
done
# loop all DefaultConfigs directories
for i in `seq 0 31` ; do
    CUR_DIR=${CONFIGS_DIR_DEFAULT}${i}/
    ${PATCH_TOOL} "${CUR_DIR}"
    RET=$?
    if [ "${EXIT_ERROR}" -eq "${RET}" ] ; then
        exit ${EXIT_ERROR}
    fi
done

exit ${EXIT_OK}

