#!/bin/sh

### script file name
SCRIPT_NAME=$(basename $0)

CONFIGS_DIR_WORKING="/var/Counter/configs/"
CONFIGS_DIR_DEFAULT="/var/Counter/DefaultConfigs/"
RES_PARAM_FILE_NAME="resolution.param"

# The reference (the update firmware version)
REF_VER_MAJOR=1
REF_VER_MINOR=30

# The reference file size [byte] for resolution parameter set files
SIZE_REF=16
# The current version file size [byte] for resolution parameter set files
SIZE_ORG=12

# exit codes
EXIT_OK=0
EXIT_ERROR=1


# parameter 1 - file name
Patch_File()
{
    FILE=${1}
    SIZE=`stat -c %s ${FILE} 2>/dev/null`
    # file size shall be same as reference file size
    if [ ${SIZE} -ne ${SIZE_REF} ] ; then
        if [ ${SIZE} -eq ${SIZE_ORG} ] ; then
            # patch file with AutoFpga value = 0 (4 byte)
            dd if=/dev/zero conv=notrunc bs=1 count=4 >> ${FILE} 2>/dev/null
            # check result (new file size)
            SIZE=`stat -c %s ${FILE} 2>/dev/null`
            if [ ${SIZE} -ne ${SIZE_REF} ] ; then
                # error, file size shall be equal to reference file size now cause its patched
                # TODO what shall we do here ?
                logger -p user.warning "${SCRIPT_NAME}: patching failed, new file size for '${FILE}' not equal to reference size (${SIZE_REF})."
            else
                logger -p user.notice "${SCRIPT_NAME}: '${FILE}' patched successfully."
            fi
        else
            # error
            # TODO what shall we do here ?
            logger -p user.warning "${SCRIPT_NAME}: could not patch '${FILE}' (invalid file size (${SIZE} byte) detected)."
        fi
    else 
        # error
        # TODO what shall we do here ?
        logger -p user.warning "${SCRIPT_NAME}: could not patch '${FILE}' (invalid file size (${SIZE} byte) detected)."
    fi
}



#### script starts here ####
### check and patch resolution.param and resolution_default.param files:
### same FPGA image shall be loaded as in SW version < 1.30


# get current firmware version
VERSION_CURRENT=`cat /version.txt`
CUR_VER_MAJOR=`echo ${VERSION_CURRENT} | awk 'BEGIN {FS="."}{print $1}'`
CUR_VER_MINOR=`echo ${VERSION_CURRENT} | awk 'BEGIN {FS="."}{print $2}'`

# check version (major and minor) against reference
# try to patch if current version lower than reference version
if [ ${CUR_VER_MAJOR} -lt ${REF_VER_MAJOR} ] ; then
    # patch it (do nothing here)
    test 2>/dev/null
elif [ ${CUR_VER_MAJOR} -eq ${REF_VER_MAJOR} ] ; then
    if [ ${CUR_VER_MINOR} -lt ${REF_VER_MINOR} ] ; then
        # patch it (do nothing here)
        test 2>/dev/null
    else
        # do nothing (exit)
        exit ${EXIT_OK}
    fi
else
    # do nothing (exit)
    exit ${EXIT_OK}
fi


# check and patch all available working files
FILES=`find ${CONFIGS_DIR_WORKING} -iname ${RES_PARAM_FILE_NAME}`
for i in ${FILES} ; do
    Patch_File ${i}
done


# check and patch all available default files
FILES=`find ${CONFIGS_DIR_DEFAULT} -iname ${RES_PARAM_FILE_NAME}`
for i in ${FILES} ; do
    Patch_File ${i}
done


exit ${EXIT_OK}
